@@ -45,6 +45,7 @@ $template->assign("languages", $languages);
 
 $user = new user();
 $project = new project();
+$companyObj = new company();
 $theset = new settings();
 $mainclasses = array("desktop" => "",
     "profil" => "",
@@ -405,7 +406,7 @@ if ($action == "index") {
                 if (!empty($user["email"])) {
                     // send email
                     $themail = new emailer($settings);
-                    $themail->send_mail($user["email"], $langfile["projectassignedsubject"] , $langfile["hello"] . ",<br /><br/>" . $langfile["projectassignedtext"] . " <a href = \"" . $url . "manageproject.php?action=showproject&id=$id\">" . $url . "manageproject.php?action=showproject&id=$add</a>");
+                    $themail->send_mail($user["email"], $langfile["projectassignedsubject"] , $langfile["hello"] . ",<br /><br/>" . $langfile["projectassignedtext"] . " <a href = \"" . $url . "manageproject.php?action=showproject&id=$add\">" . $url . "manageproject.php?action=showproject&id=$add</a>");
                 }
             }
         }
@@ -429,6 +430,59 @@ if ($action == "index") {
         // header("Location: admin.php?action=projects&mode=deleted");
         echo "ok";
     }
+} elseif ($action == "customers") {
+    $classes = array("overview" => "overview",
+        "customer" => "active",
+        "system" => "system",
+        "users" => "users"
+        );
+    $title = $langfile['customeradministration'];
+    $template->assign("title", $title);
+    $template->assign("classes", $classes);
+    $allcust = $companyObj->getAllCompanies();
+    //$clopros = $project->getProjects(0, 10000);
+   /* $i = 0;
+    $users = $user->getAllUsers(1000000);
+    if (!empty($opros)) {
+        foreach($opros as $opro) {
+            $membs = $project->getProjectMembers($opro["ID"], 1000);
+            $opros[$i]['members'] = $membs;
+            $i = $i + 1;
+        }
+        $template->assign("opros", $opros);
+    }*/
+
+    $template->assign("allcust", $allcust);
+    $template->display("admincustomers.tpl");
+} elseif ($action == "addcust") {
+	if (!$userpermissions["customers"]["add"]) {
+		$errtxt = $langfile["nopermission"];
+		$noperm = $langfile["accessdenied"];
+		$template->assign("errortext", "$errtxt<br>$noperm");
+		$template->display("error.tpl");
+		die();
+	}
+
+	if (!$end) {
+		$end = 0;
+	}
+	$data = array(
+			'company' => getArrayVal($_POST, "company"),
+			'contact' => getArrayVal($_POST, "contact"),
+			'email' => getArrayVal($_POST, "email"),
+			'phone' => getArrayVal($_POST, "tel1"),
+			'mobile' => getArrayVal($_POST, "tel2"),
+			'url' => getArrayVal($_POST, "web"),
+			'address' => getArrayVal($_POST, "address"),
+			'zip' => getArrayVal($_POST, "zip"),
+			'city' => getArrayVal($_POST, "city"),
+			'country' => getArrayVal($_POST, "country"),
+			'state' => getArrayVal($_POST, "state"),
+			'desc' => getArrayVal($_POST, "desc")
+	);
+	$add = $companyObj->add($data);
+	if ($add)
+		header("Location: admin.php?action=customers&mode=added");
 } elseif ($action == "system") {
     $classes = array("overview" => "overview",
         "system" => "active",
